@@ -1,4 +1,4 @@
-package LedgerSMB::Installer::OS::unix v0.999.1;
+package LedgerSMB::Installer::OS::unix v0.999.2;
 
 use v5.20;
 use experimental qw(signatures);
@@ -89,6 +89,8 @@ sub untar($self, $tar, $target, %options) {
     my @cmd = ($self->{cmd}->{tar}, 'xzf', $tar, '-C', $target);
     push @cmd, ('--strip-components', $options{strip_components})
         if $options{strip_components};
+    push @cmd, '--no-same-owner'
+        if $options{no_same_owner};
     $log->debug( 'system(): ' . join(' ', map { "'$_'" } @cmd ) );
     system(@cmd) == 0
         or croak $log->fatal( "Failure executing tar: $!" );
